@@ -284,6 +284,11 @@ regular expression that matches all addresses used by your RT.  This lets RT
 avoid sending mail to itself.  It will also hide RT addresses from the list of 
 "One-time Cc" and Bcc lists on ticket reply.
 
+If you have a number of addresses configured in your RT database already, you
+can generate a naive first pass regexp by using
+
+    perl etc/upgrade/generate-rtaddressregexp
+
 =cut
 
 Set($RTAddressRegexp , undef);
@@ -315,24 +320,6 @@ F<RT/User_Local.pm>
 
 Set($CanonicalizeOnCreate, 0);
 
-=item C<$SenderMustExistInExternalDatabase>
-
-If C<$SenderMustExistInExternalDatabase> is true, RT will refuse to
-create non-privileged accounts for unknown users if you are using
-the C<$LookupSenderInExternalDatabase> option.
-Instead, an error message will be mailed and RT will forward the
-message to C<$RTOwner>.
-
-If you are not using C<$LookupSenderInExternalDatabase>, this option
-has no effect.
-
-If you define an AutoRejectRequest template, RT will use this
-template for the rejection message.
-
-=cut
-
-Set($SenderMustExistInExternalDatabase , undef);
-
 =item C<$ValidateUserEmailAddresses>
 
 If C<$ValidateUserEmailAddresses> is true, RT will refuse to create users with
@@ -388,6 +375,11 @@ or 'qmail'.
 Note that you should remove the '-t' from C<$SendmailArguments>
 if you use 'sendmail' rather than 'sendmailpipe'
 
+For testing purposes, or to simply disable sending mail out into the world, you
+can set C<$MailCommand> to 'testfile' which writes all mail to a temporary
+file.  RT will log the location of the temporary file so you can extract mail
+from it afterwards.
+
 =cut
 
 Set($MailCommand , 'sendmailpipe');
@@ -407,8 +399,11 @@ Set($SetOutgoingMailFrom, 0);
 =item C<$OverrideOutgoingMailFrom>
 
 C<$OverrideOutgoingMailFrom> is used for overwriting the Correspond
-address of the queue. The option is a hash reference of queue name to
-email address.
+address of the queue as it is handed to sendmail -f. This helps force
+the From_ header away from www-data or other email addresses that show
+up in the "Sent by" line in Outlook.
+
+The option is a hash reference of queue name to email address.
 
 If there is no ticket involved, then the value of the C<Default> key will be
 used.
@@ -616,7 +611,7 @@ Set($UseFriendlyToLine, 0);
 
 =item C<$FriendlyToLineFormat>
 
-C<sprintf()> format of the friendly 'From:' header; its arguments
+C<sprintf()> format of the friendly 'To:' header; its arguments
 are WatcherType and TicketId.
 
 =cut
@@ -1102,6 +1097,16 @@ displayed in kilobytes. If set to C<'b'>, then sizes will be bytes.
 
 Set($AttachmentUnits, undef);
 
+=item C<$EditCustomFieldsSingleColumn>
+
+When displaying a list of Ticket Custom Fields for editing, RT defaults
+to a 2 column list.  If you set this to 1, it will instead display the
+Custom Fields in a single column.
+
+=cut
+
+Set($EditCustomFieldsSingleColumn, 0);
+
 =item C<$RedistributeAutoGeneratedMessages>
 
 Should RT redistribute correspondence that it identifies as
@@ -1230,6 +1235,19 @@ via SSL encrypted HTTP connections.
 
 Set($WebSecureCookies, 0);
 
+=item C<$WebHttpOnlyCookies>
+
+Default RT's session cookie to not being directly accessible to
+javascript.  The content is still sent during regular and AJAX requests,
+and other cookies are unaffected, but the session-id is less
+programmatically accessible to javascript.  Turning this off should only
+be necessary in situations with odd client-side authentication
+requirements.
+
+=cut
+
+Set($WebHttpOnlyCookies, 1);
+
 =item C<$WebFlushDbCacheEveryRequest>
 
 By default, RT clears its database cache after every page view.
@@ -1282,6 +1300,29 @@ search results in RT. Choose from [0, 120, 300, 600, 1200, 3600, 7200].
 
 Set($SearchResultsRefreshInterval, 0);
 
+=item C<$ResolveDefaultUpdateType>
+
+Set the default Update Type when clicking the Resolve link in the Ticket
+links tab.
+
+  Comment            Comments (Not sent to requestors)
+  Respond            Reply to requestors
+
+=cut
+
+Set($ResolveDefaultUpdateType, 'Comment');
+
+=item C<$SuppressAutoOpenOnUpdate>
+
+When users click Comment or Reply on a new ticket in the web UI, the default
+status for the ticket gets set to 'open' if the status is currently 'new'.
+Setting this option to 1 will suppress that behavior and leave the default
+status as 'new'. This option can be overridden by users in their preferences.
+
+=cut
+
+Set($SuppressAutoOpenOnUpdate, 0);
+
 =item C<$OldestTransactionsFirst>
 
 By default, RT shows newest transactions at the bottom of the ticket
@@ -1476,12 +1517,14 @@ Set(
 
 =item C<$ChartsTimezonesInDB>
 
-Dates are stored using UTC timezone in the DB, so charts groupped
+RT stores dates using the UTC timezone in the DB, so charts grouped
 by dates and time are not representative. Set C<$ChartsTimezonesInDB>
-to a true value to enable timezones conversions using DB's
-capabilities. You may need to do some work on DB side to use this
+to a true value to enable timezone conversions using your DB's
+capabilities. You may need to do some work on the DB side to use this
 feature, read more in F<docs/timezones_in_charts.pod>.
 
+At this time, this feature only applies to MySQL and PostgreSQL.
+
 =cut
 
 Set( $ChartsTimezonesInDB, 0 );
@@ -1664,7 +1707,7 @@ Set($AmbiguousDayInFuture, 0);
 
 =head1 Approval Configuration
 
-Configration for the approvl system
+Configuration for the approval system
 
 =over 4
 
