@@ -1,40 +1,40 @@
 # BEGIN BPS TAGGED BLOCK {{{
-# 
+#
 # COPYRIGHT:
-# 
-# This software is Copyright (c) 1996-2009 Best Practical Solutions, LLC
-#                                          <jesse@bestpractical.com>
-# 
+#
+# This software is Copyright (c) 1996-2011 Best Practical Solutions, LLC
+#                                          <sales@bestpractical.com>
+#
 # (Except where explicitly superseded by other copyright notices)
-# 
-# 
+#
+#
 # LICENSE:
-# 
+#
 # This work is made available to you under the terms of Version 2 of
 # the GNU General Public License. A copy of that license should have
 # been provided with this software, but in any event can be snarfed
 # from www.gnu.org.
-# 
+#
 # This work is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 or visit their web page on the internet at
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html.
-# 
-# 
+#
+#
 # CONTRIBUTION SUBMISSION POLICY:
-# 
+#
 # (The following paragraph is not intended to limit the rights granted
 # to you to modify and distribute this software under the terms of
 # the GNU General Public License and is only of importance to you if
 # you choose to contribute your changes and enhancements to the
 # community by submitting them to Best Practical Solutions, LLC.)
-# 
+#
 # By intentionally submitting any modifications, corrections or
 # derivatives to this work, or any other work intended for use with
 # Request Tracker, to Best Practical Solutions, LLC, you confirm that
@@ -43,7 +43,7 @@
 # royalty-free, perpetual, license to use, copy, create derivative
 # works based on those contributions, and sublicense and distribute
 # those contributions and any derivatives thereof.
-# 
+#
 # END BPS TAGGED BLOCK }}}
 
 package RT::Tickets;
@@ -349,6 +349,18 @@ sub Query {
     return ($_[0]->{_sql_query});
 }
 
+{
+my %inv = (
+    '=' => '!=', '!=' => '=', '<>' => '=',
+    '>' => '<=', '<' => '>=', '>=' => '<', '<=' => '>',
+    'is' => 'IS NOT', 'is not' => 'IS',
+    'like' => 'NOT LIKE', 'not like' => 'LIKE',
+    'matches' => 'NOT MATCHES', 'not matches' => 'MATCHES',
+    'startswith' => 'NOT STARTSWITH', 'not startswith' => 'STARTSWITH',
+    'endswith' => 'NOT ENDSWITH', 'not endswith' => 'ENDSWITH',
+);
+
+my %range = map { $_ => 1 } qw(> >= < <=);
 
 sub ClassifySQLOperation {
     my $self = shift;
@@ -364,18 +376,8 @@ sub ClassifySQLOperation {
         $is_null = 1;
     }
 
-    my %inv = (
-        '=' => '!=', '!=' => '=', '<>' => '=',
-        '>' => '<=', '<' => '>=', '>=' => '<', '<=' => '>',
-        'is' => 'IS NOT', 'is not' => 'IS',
-        'like' => 'NOT LIKE', 'not like' => 'LIKE',
-        'matches' => 'NOT MATCHES', 'not matches' => 'MATCHES',
-        'startswith' => 'NOT STARTSWITH', 'not startswith' => 'STARTSWITH',
-        'endswith' => 'NOT ENDSWITH', 'not endswith' => 'ENDSWITH',
-    );
-
-    return ($is_negative, $is_null, $inv{lc $op});
-}
+    return ($is_negative, $is_null, $inv{lc $op}, $range{lc $op});
+} }
 
 1;
 
