@@ -1,40 +1,40 @@
 # BEGIN BPS TAGGED BLOCK {{{
-# 
+#
 # COPYRIGHT:
-#  
-# This software is Copyright (c) 1996-2009 Best Practical Solutions, LLC 
-#                                          <jesse@bestpractical.com>
-# 
+#
+# This software is Copyright (c) 1996-2011 Best Practical Solutions, LLC
+#                                          <sales@bestpractical.com>
+#
 # (Except where explicitly superseded by other copyright notices)
-# 
-# 
+#
+#
 # LICENSE:
-# 
+#
 # This work is made available to you under the terms of Version 2 of
 # the GNU General Public License. A copy of that license should have
 # been provided with this software, but in any event can be snarfed
 # from www.gnu.org.
-# 
+#
 # This work is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 or visit their web page on the internet at
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html.
-# 
-# 
+#
+#
 # CONTRIBUTION SUBMISSION POLICY:
-# 
+#
 # (The following paragraph is not intended to limit the rights granted
 # to you to modify and distribute this software under the terms of
 # the GNU General Public License and is only of importance to you if
 # you choose to contribute your changes and enhancements to the
 # community by submitting them to Best Practical Solutions, LLC.)
-# 
+#
 # By intentionally submitting any modifications, corrections or
 # derivatives to this work, or any other work intended for use with
 # Request Tracker, to Best Practical Solutions, LLC, you confirm that
@@ -43,13 +43,13 @@
 # royalty-free, perpetual, license to use, copy, create derivative
 # works based on those contributions, and sublicense and distribute
 # those contributions and any derivatives thereof.
-# 
+#
 # END BPS TAGGED BLOCK }}}
-package RT::URI;;
+
+package RT::URI;
 
 use strict;
-use vars qw/@ISA/;
-@ISA = qw(RT::Base);
+use base 'RT::Base';
 
 use RT::URI::base;
 use Carp;
@@ -136,20 +136,23 @@ sub FromURI {
 	$scheme = $1;
     }
     else {
-        $RT::Logger->warning("$self Could not determine a URI scheme for $uri");
-		return (undef);
+        $RT::Logger->warning("Could not determine a URI scheme for $uri");
+        return (undef);
     }
      
     # load up a resolver object for this scheme  
     $self->_GetResolver($scheme);
     
     unless ($self->Resolver->ParseURI($uri)) {
-        $RT::Logger->warning("Resolver ".ref($self->Resolver)." could not parse $uri");
+        $RT::Logger->warning( "Resolver "
+              . ref( $self->Resolver )
+              . " could not parse $uri, maybe Organization config was changed?"
+        );
         $self->{resolver} = RT::URI::base->new( $self->CurrentUser ); # clear resolver
     	return (undef);
     }
 
-return(1);
+    return(1);
 
 }
 
@@ -157,7 +160,7 @@ return(1);
 
 # {{{ _GetResolver
 
-=private _GetResolver <scheme>
+=head2 _GetResolver <scheme>
 
 Gets an RT URI resolver for the scheme <scheme>. 
 Falls back to a null resolver. RT::URI::base.
@@ -172,16 +175,16 @@ sub _GetResolver {
     my $resolver;
 
     
-       eval " 
-            require RT::URI::$scheme;
-            \$resolver = RT::URI::$scheme->new(\$self->CurrentUser);
-       ";
+    eval " 
+        require RT::URI::$scheme;
+        \$resolver = RT::URI::$scheme->new(\$self->CurrentUser);
+    ";
      
-        if ($resolver) {
+    if ($resolver) {
         $self->{'resolver'} = $resolver;
-        } else {
+    } else {
         $self->{'resolver'} = RT::URI::base->new($self->CurrentUser); 
-        }
+    }
 
 }
 
@@ -191,8 +194,8 @@ sub _GetResolver {
 
 =head2 Scheme
 
-Returns a local object id for this content.  You are expected to know what sort of object this is the Id 
-of 
+Returns a local object id for this content.  You are expected to know
+what sort of object this is the Id of
 
 =cut
 
@@ -261,9 +264,9 @@ sub IsLocal {
 sub AsHREF {
     my $self = shift;
     return $self->Resolver->HREF;
-
 }
-=head Resolver
+
+=head2 Resolver
 
 Returns this URI's URI resolver object
 
@@ -275,9 +278,6 @@ sub Resolver {
     return ($self->{'resolver'});
 }
 
-eval "require RT::URI_Vendor";
-die $@ if ($@ && $@ !~ qr{^Can't locate RT/URI_Vendor.pm});
-eval "require RT::URI_Local";
-die $@ if ($@ && $@ !~ qr{^Can't locate RT/URI_Local.pm});
+RT::Base->_ImportOverlays();
 
 1;
